@@ -18,15 +18,13 @@ module MCollective
 
       # Determines the default command to run for puppet agent
       #
-      # On windows the installer sets up the Path so this should
-      # work with default relying on the path, AIO on Unix does not
-      # so check those and default to that
+      # Return the puppet script to execute on the local platform.
       def default_agent_command
-        if File.exist?("/opt/puppetlabs/bin/puppet")
-          "/opt/puppetlabs/bin/puppet agent"
+        if Util.windows?
+          "puppet.bat"
         else
-          "puppet agent"
-        end
+          "puppet"
+        end + " agent"
       end
 
       def run(command, options)
@@ -46,6 +44,12 @@ module MCollective
         else
           # On Unices double fork and exec to run puppet in a disowned child
           child = fork {
+            # If relying on Puppet on PATH, ensure the default AIO path is included.
+            # On Windows, the MSI adds Puppet to the PATH.
+            if command.start_with?("puppet ")
+              ENV["PATH"] += ":/opt/puppetlabs/bin"
+            end
+
             grandchild = fork {
               exec command
             }
